You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hbase.apache.org by st...@apache.org on 2012/10/11 08:58:08 UTC

svn commit: r1396928 - /hbase/trunk/hbase-server/src/main/java/org/apache/hadoop/hbase/master/MasterFileSystem.java

Author: stack
Date: Thu Oct 11 06:58:07 2012
New Revision: 1396928

URL: http://svn.apache.org/viewvc?rev=1396928&view=rev
Log:
HBASE-6971 .META. directory does not contain .tableinfo serialization

Modified:
    hbase/trunk/hbase-server/src/main/java/org/apache/hadoop/hbase/master/MasterFileSystem.java

Modified: hbase/trunk/hbase-server/src/main/java/org/apache/hadoop/hbase/master/MasterFileSystem.java
URL: http://svn.apache.org/viewvc/hbase/trunk/hbase-server/src/main/java/org/apache/hadoop/hbase/master/MasterFileSystem.java?rev=1396928&r1=1396927&r2=1396928&view=diff
==============================================================================
--- hbase/trunk/hbase-server/src/main/java/org/apache/hadoop/hbase/master/MasterFileSystem.java (original)
+++ hbase/trunk/hbase-server/src/main/java/org/apache/hadoop/hbase/master/MasterFileSystem.java Thu Oct 11 06:58:07 2012
@@ -380,16 +380,12 @@ public class MasterFileSystem {
     if (!FSUtils.rootRegionExists(fs, rd)) {
       bootstrap(rd, c);
     }
-    createRootTableInfo(rd);
-    return rd;
-  }
 
-  private void createRootTableInfo(Path rd) throws IOException {
-    // Create ROOT tableInfo if required.
-    if (!FSTableDescriptors.isTableInfoExists(fs, rd,
-        Bytes.toString(HRegionInfo.ROOT_REGIONINFO.getTableName()))) {
-      FSTableDescriptors.createTableDescriptor(HTableDescriptor.ROOT_TABLEDESC, this.conf);
-    }
+    // Create tableinfo-s for ROOT and META if not already there.
+    FSTableDescriptors.createTableDescriptor(fs, rd, HTableDescriptor.ROOT_TABLEDESC, false);
+    FSTableDescriptors.createTableDescriptor(fs, rd, HTableDescriptor.META_TABLEDESC, false);
+
+    return rd;
   }
 
   private static void bootstrap(final Path rd, final Configuration c)